# HTTPSecuritySettings

Configuration of an HTTP Application's security model.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**csp** | [**CSPSettings**](CSPSettings.md) |  | 
**cors** | [**CORSSettings**](CORSSettings.md) |  | 
**hsts** | [**HSTSSettings**](HSTSSettings.md) |  | 
**xss_protection** | [**XSSSettings**](XSSSettings.md) |  | 
**certificate_transparency** | [**CertificateTransparencySettings**](CertificateTransparencySettings.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


